@@ -18,6 +18,11 @@ def clip_quantile(features: pd.DataFrame, lower_quantile=0.01, upper_quantile=0.
 
 def _apply_timestamp_ohlc_resample(ohlc_row):
 
+    if len(ohlc_row) == 0:
+        # todo: potential unwanted data loss
+        # happens normally with none inferable freq (e.x. datatimeindex with missing values like weekends)
+        return
+
     row = ohlc_row.iloc[0].copy()
     row["Open"] = ohlc_row["Open"].iloc[0]
     row["Close"] = ohlc_row["Close"].iloc[-1]
@@ -52,7 +57,9 @@ def timestamp_ohlc_resample(ohlc: pd.DataFrame, resample_freq: str) -> pd.DataFr
     resampled = (ohlc
                  .groupby(pd.Grouper(freq=resample_freq))
                  .apply(_apply_timestamp_ohlc_resample)
-                 # .dropna(how="all")
+                  # for missing data (e.x. weekends) it still creates nan!!
+                  # so, rows with all nan likely to be result of this group by - so, delete them all
+                 .dropna(how="all")
                  )
     return resampled
 
